emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/guess-language dfd62cc 047/101: Added support for Spani


From: Stefan Monnier
Subject: [elpa] externals/guess-language dfd62cc 047/101: Added support for Spanish.
Date: Sat, 23 Feb 2019 10:34:40 -0500 (EST)

branch: externals/guess-language
commit dfd62cc037c83907627dc6019084c4589f1c4c67
Author: Titus von der Malsburg <address@hidden>
Commit: Titus von der Malsburg <address@hidden>

    Added support for Spanish.
---
 README.org        |  3 ++-
 guess-language.el | 10 ++++++----
 2 files changed, 8 insertions(+), 5 deletions(-)

diff --git a/README.org b/README.org
index 35a5c47..2605fa1 100644
--- a/README.org
+++ b/README.org
@@ -9,7 +9,7 @@
 
 I write a lot of text in multiple languages and was getting tired of 
constantly having to switch the dictionary of my spell-checker.  In true Emacs 
spirit, I decided to dust off my grandpa's parentheses and wrote some code to 
address this problem.  The result is ~guess-language-mode~, a minor mode for 
Emacs that guesses the language of the current paragraph and then changes the 
dictionary of ispell and the language settings of typo-mode.  It also reruns 
Flyspell on the current paragraph, [...]
 
-Currently, the following languages are supported: Czech, Danish, Dutch, 
English, Finnish, French, German, Italian, Norwegian, Polish, Portuguese, 
Russian, Slovak, Slovenian, Swedish.  It is very easy to add more languages and 
this repository includes the necessary language statistics for 49 additional 
languages.  (These were copied from 
[[https://github.com/kent37/guess-language][guess_language.py]].)
+Currently, the following languages are supported: Czech, Danish, Dutch, 
English, Finnish, French, German, Italian, Norwegian, Polish, Portuguese, 
Russian, Slovak, Slovenian, Spanish, Swedish.  It is very easy to add more 
languages and this repository includes the necessary language statistics for 49 
additional languages.  (These were copied from 
[[https://github.com/kent37/guess-language][guess_language.py]].)
 
 ** Prerequisites
 
@@ -33,6 +33,7 @@ Available languages at this time:
 | ~da~           | Danish     |
 | ~nl~           | Dutch      |
 | ~en~           | English    |
+| ~es~           | Spanish    |
 | ~fi~           | Finnish    |
 | ~fr~           | French     |
 | ~de~           | German     |
diff --git a/guess-language.el b/guess-language.el
index 640e2af..b17ffa9 100644
--- a/guess-language.el
+++ b/guess-language.el
@@ -33,9 +33,9 @@
 ;; The detection algorithm is based on counts of character
 ;; trigrams.  At this time, supported languages are Czech, Danish,
 ;; Dutch, English, Finnish, French, German, Italian, Norwegian,
 ;; Polish, Portuguese, Russian, Slovak, Slovenian, Swedish.  Adding
 ;; further languages is very easy and this package already contains
 ;; language statistics for 49 additional languages.
 
 ;;; Code:
 
@@ -63,6 +63,7 @@ Uses ISO 639-1 identifiers.  Currently supported languages 
are:
   ru: Russian
   sk: Slovak
   sl: Slovenian
+  es: Spanish
   sv: Swedish"
   :type '(repeat symbol)
   :group 'guess-language)
@@ -90,8 +91,9 @@ little material to reliably guess the language."
     (ru . ("russian" "Russian"))
     ;; Languages with ispell but no typo support:
     (da . ("dansk" nil))
-    (nl . ("nederlands" nil))
+    (es . ("spanish" nil))
     (nb . ("norsk" nil))
+    (nl . ("nederlands" nil))
     (pl . ("polish" nil))
     (pt . ("portuguese" nil))
     (sk . ("slovak" nil))
@@ -33,9 +33,9 @@
 ;; trigrams.  At this time, supported languages are Czech, Danish,
 ;; Dutch, English, Finnish, French, German, Italian, Norwegian,
-;; Polish, Portuguese, Russian, Slovak, Slovenian, Swedish.  Adding
-;; further languages is very easy and this package already contains
-;; language statistics for 49 additional languages.
+;; Polish, Portuguese, Russian, Slovak, Slovenian, Spanish,
+;; Swedish.  Adding further languages is very easy and this package
+;; already contains language statistics for 49 additional languages.
 
 ;;; Code:



reply via email to

[Prev in Thread] Current Thread [Next in Thread]